@@ -70,13 +70,25 @@ file_share.file_endpoint <- function(endpoint, name, ...)
 print.file_share <- function(x, ...)
 {
     cat("Azure file share '", x$name, "'\n", sep="")
-    cat(sprintf("URL: %s\n", paste0(x$endpoint$url, x$name)))
+    url <- httr::parse_url(x$endpoint$url)
+    url$path <- x$name
+    cat(sprintf("URL: %s\n", httr::build_url(url)))
+
     if(!is_empty(x$endpoint$key))
         cat("Access key: <hidden>\n")
     else cat("Access key: <none supplied>\n")
+
+    if(!is_empty(x$endpoint$token))
+    {
+        cat("Azure Active Directory token:\n")
+        print(x$endpoint$token)
+    }
+    else cat("Azure Active Directory token: <none supplied>\n")
+
     if(!is_empty(x$endpoint$sas))
         cat("Account shared access signature: <hidden>\n")
     else cat("Account shared access signature: <none supplied>\n")
+
     cat(sprintf("Storage API version: %s\n", x$endpoint$api_version))
     invisible(x)
 }
